.. es-query-gen documentation master file, created by
   sphinx-quickstart on Sun Jan 18 15:36:51 2026.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

es-query-gen documentation
==========================

Add your content using ``reStructuredText`` syntax. See the
`reStructuredText <https://www.sphinx-doc.org/en/master/usage/restructuredtext/index.html>`_
documentation for details.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   api

